CameraViewer

Struct CameraViewer 

pub struct CameraViewer { /* private fields */ }
Renders the latest frame produced by a Camera.

Example

use freya::{
    camera::*,
    prelude::*,
};

fn app() -> impl IntoElement {
    let camera = use_camera(CameraConfig::default);
    CameraViewer::new(camera)
}

Implementations

Source

impl CameraViewer

pub fn new(camera: Camera) -> Self

pub fn corner_radius(self, corner_radius: impl Into<CornerRadius>) -> Self

pub fn loading_placeholder(self, placeholder: impl Into<Element>) -> Self

Custom element rendered while the camera has not yet produced a frame.

pub fn error_renderer( self, renderer: impl Into<Callback<CameraError, Element>>, ) -> Self

Custom element rendered when the camera fails before producing any frame.