pub struct CameraViewer { /* private fields */ }Expand description
Implementations
Sourceimpl CameraViewer
impl CameraViewer
pub fn new(camera: Camera) -> Self
pub fn corner_radius(self, corner_radius: impl Into<CornerRadius>) -> Self
Sourcepub fn loading_placeholder(self, placeholder: impl Into<Element>) -> Self
pub fn loading_placeholder(self, placeholder: impl Into<Element>) -> Self
Custom element rendered while the camera has not yet produced a frame.
Sourcepub fn error_renderer(
self,
renderer: impl Into<Callback<CameraError, Element>>,
) -> Self
pub fn error_renderer( self, renderer: impl Into<Callback<CameraError, Element>>, ) -> Self
Custom element rendered when the camera fails before producing any frame.